#!/usr/bin/env python3

from __future__ import print_function
from Adafruit_Thermal import *
import time, urllib, json
from PIL import Image, ImageDraw

from random import seed
from random import randint

from datetime import date
from datetime import datetime
import calendar
import requests
import os
import qrcode

##Initialize Thermal Printer
printer = Adafruit_Thermal("/dev/serial0", 19200, timeout=5)

##Add your individual API key here from Spoonacular.com 
API_KEY = "Your API key from spoonacular.com"

##Generate random number to index a random recipe in spoonacular. 
##Spoonacular claims to have a catalog of over 360,000 recipes,
##so I generate a random number up to that and search spoonacular
status = 0;

##Checks to see if the random number called to spoonacular returned a recipe.
##If not, try again until successful
while status != 200:
    for _ in range(1):
        int_value = randint(1,360000)

    str_value = str(int_value)
    url = "https://api.spoonacular.com/recipes/"+str_value+"/information?" + API_KEY
    r  = requests.get(url)
    status = r.status_code

##Store json data into variable
rawdata = r.json()

##Obtain pertinent information from the rawdata
recipetitle = rawdata['title']
summary = rawdata['summary']
cooktime = rawdata['readyInMinutes']
spoonscore = rawdata['spoonacularScore']
websiteurl = rawdata['sourceUrl']

##Convert to string variable
cooktime = str(cooktime)
spoonscore = str(spoonscore)

##This will print to your command line. Can uncomment if desired
#print("Recipe: " + recipetitle)
#print("Cooktime: " + cooktime + " minutes")
#print("Spoonacular Score: " + spoonscore + "%")
#print(websiteurl)

##This step makes a qr code and saves the image to your folder where this code is stored
qr = qrcode.make(websiteurl)
qr.save('myQR.png')

##Open the image and resize in order to fit onto thermal print reciept
img = Image.open('myQR.png')
newsize = (200, 200)
img2 = img.resize(newsize)

##Print out desired recipe into
printer.feed(1)

##Print "Recipe of the Day" header
printer.boldOn()
printer.underlineOn()
printer.setSize('M')
printer.justify('C')
printer.println('Recipe of the Day')
printer.feed(1)

##Print recipe title
printer.setSize('S')
printer.justify('L')
printer.print("Recipe:")
printer.underlineOff()
printer.print(" ")
printer.boldOff()
printer.println(recipetitle)
printer.feed(1)

##Print recipe cooktime
printer.boldOn()
printer.underlineOn()
printer.print("Cooktime:")
printer.underlineOff()
printer.print(" ")
printer.boldOff()
printer.print(cooktime)
printer.println(" minutes")
printer.feed(1)

##Print recipe spoonacular score
printer.boldOn()
printer.underlineOn()
printer.print("Spoonacular Score:")
printer.underlineOff()
printer.print(" ")
printer.boldOff()
printer.print(spoonscore)
printer.println("%")
printer.feed(1)

##Print recipe qrcode image
printer.printImage(img2, True)
printer.feed(4)

##Remove saved qr code image in folder
os.remove("myQR.png")
